==> django_scaffolding_tools-0.10.2.tar.gz: django_scaffolding_tools-0.10.2/tests/conftest.py <==
import json
from datetime import datetime
from pathlib import Path

import pytest


@pytest.fixture(scope='session')
def output_folder():
    folder = Path(__file__).parent.parent / 'output'
    return folder


@pytest.fixture(scope='session')
def fixtures_folder():
    folder = Path(__file__).parent.parent / 'tests' / 'fixtures'
    return folder


@pytest.fixture(scope='session')
def camel_case_dict():
    data = {
        "firstName": "Luis",
        "lastName": "Wayne",
        "IMEI": "HJ8777"
    }
    return data


@pytest.fixture(scope='session')
def model_list_for_serializers():
    with open('./fixtures/model_list.json', 'r') as json_file:
        model_list = json.load(json_file)
    return model_list


@pytest.fixture()
def d_local_data_dict():
    data = {
        "id": "D-4-be8eda8c-5fe7-49dd-8058-4ddaac00611b",
        "amount": 72.00,
        "status": "PAID",
        "status_detail": "The payment was paid.",
        "status_code": "200",
        "currency": "USD",
        "country": "AR",
        "payment_method_id": "RP",
        "payment_method_type": "TICKET",
        "payment_method_flow": "REDIRECT",
        "payer": {
            "name": "Nino Deicas",
            "user_reference": "US-jmh3gb4kj5h34",
            "email": "buyer@gmail.com",
            "address": {
                "street": "123th street",
                "state": "FL",
                "zip_code": "99999999"
            }
        },
        "order_id": "4m1OdghPUQtg",
        "notification_url": "http://www.merchant.com/notifications",
        "created_date": "2019-06-26T15:17:31.000+0000",
        "user": {
            "id": 1,
            "username": "bwayne",
            "created": datetime(2022, 10, 21, 11, 56, 25, 23)
        }
    }
    return data

==> django_scaffolding_tools-0.11.1.tar.gz: django_scaffolding_tools-0.11.1/tests/conftest.py <==
import json
from datetime import datetime
from pathlib import Path

import pytest


@pytest.fixture(scope="session")
def output_folder():
    folder = Path(__file__).parent.parent / "output"
    return folder


@pytest.fixture(scope="session")
def fixtures_folder():
    folder = Path(__file__).parent.parent / "tests" / "fixtures"
    return folder


@pytest.fixture(scope="session")
def camel_case_dict():
    data = {"firstName": "Luis", "lastName": "Wayne", "IMEI": "HJ8777"}
    return data


@pytest.fixture(scope="session")
def model_list_for_serializers():
    with open("./fixtures/model_list.json") as json_file:
        model_list = json.load(json_file)
    return model_list


@pytest.fixture()
def d_local_data_dict():
    data = {
        "id": "D-4-be8eda8c-5fe7-49dd-8058-4ddaac00611b",
        "amount": 72.00,
        "status": "PAID",
        "status_detail": "The payment was paid.",
        "status_code": "200",
        "currency": "USD",
        "country": "AR",
        "payment_method_id": "RP",
        "payment_method_type": "TICKET",
        "payment_method_flow": "REDIRECT",
        "payer": {
            "name": "Nino Deicas",
            "user_reference": "US-jmh3gb4kj5h34",
            "email": "buyer@gmail.com",
            "address": {"street": "123th street", "state": "FL", "zip_code": "99999999"},
        },
        "order_id": "4m1OdghPUQtg",
        "notification_url": "http://www.merchant.com/notifications",
        "created_date": "2019-06-26T15:17:31.000+0000",
        "user": {"id": 1, "username": "bwayne", "created": datetime(2022, 10, 21, 11, 56, 25, 23)},
    }
    return data
